
## Customize your Solarized

### Intro
[Solarized](http://ethanschoonover.com/solarized) is great and a lot of effort went into making it.
But at the end of a day, I often wished it had that little bit of more contrast. When working on it in complete darkness even the dark theme is to bright for me. Sometimes I'd just prefer to stare at something that is not blue but brown and a little bit darker. One size does not fit all, if you want to use a customized version of Solarized, use *sola*

### Samples
![standart solarized light](http://i.imgur.com/cOfDt10.png)
![solarized light darker](http://i.imgur.com/PaoKzHI.png)
![colors shifted](http://i.imgur.com/7XW8g3V.png)

![standart solarized dark](http://i.imgur.com/VE5geqY.png)
![solarized more contrast](http://i.imgur.com/RGOO9y8.png)
![solarized brown background](http://i.imgur.com/J855msD.png)
![solarized less colors](http://i.imgur.com/c0PkDlm.png)
